@@ -3,7 +3,9 @@ import time
 import requests
 from tqdm import tqdm
 
+from .common import npu_print, NEURO_AI_STR
 from .web.urls import TASK_STATUS_URL
+from threading import Thread
 
 FAILURE = "FAILURE"
 PENDING = "PENDING"
@@ -12,9 +14,7 @@ STOPPED = "STOPPED"
 
 TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
 
-import threading
-
-bar_suffix = "{desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} "
+bar_suffix = NEURO_AI_STR + " {desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} "
 one_hundred_percent = 100
 
 
@@ -31,15 +31,15 @@ class Task:
         self._logs = {}
         self.prints = []
         if self.callback:
-            t = threading.Thread(target=self.callback_thread)
+            t = Thread(target=self.callback_thread)
             t.start()
         if show:
             self.update()
-            print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
+            npu_print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
 
     def wait(self):
-        if self.finished():
-            return
+        # if self.finished():
+        #     return
         with tqdm(desc=self.task_type, total=one_hundred_percent,
                   bar_format=bar_suffix) as bar:
             while not self.finished():
@@ -52,7 +52,7 @@ class Task:
                 self.update(include_result=True)
                 raise Exception("ERROR for task {}: {}".format(self.task_id, self.task_result))
             if self.task_state == STOPPED:
-                print("Task has been stopped.")
+                npu_print("Task has been stopped.")
                 return
             bar.n = one_hundred_percent
 
