@@ -1,38 +1,61 @@
 import hashlib
 import math
-
 import requests
 from bson import ObjectId
-# from progress.bar import ChargingBar
 from tqdm import tqdm
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
+from datetime import datetime
 
 from .Model import Model
 from .DataLoader import DataLoader
 from .Dataset import Dataset
-from .Task import Task, bar_suffix
 from .saving.saving import save_data, determine_model, TF_str, mxnet_str, pytorch_str
 from .web.urls import TOKEN_URL, HASH_URL, UPLOAD_DATA_URL
 
+
 VERBOSITY = 1
 MIN_VERBOSITY = 1
 MID_VERBOSITY = 2
 FULL_VERBOSITY = 3
 
 _token = ""
+_project = ""
+
+utcnow = datetime.utcnow
+
+# from SO
+class bcolors:
+    PURPLE = '\033[95m'
+    OKBLUE = '\033[94m'
+    OKCYAN = '\033[96m'
+    OKGREEN = '\033[92m'
+    WARNING = '\033[93m'
+    FAIL = '\033[91m'
+    ENDC = '\033[0m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
+    ORANGE = '\33[38;5;208m'
 
 
-def api(token_, verbosity):
+levels = {"WARNING": bcolors.ORANGE, "INFO": bcolors.PURPLE}
+
+NEURO_AI_STR = f"[{bcolors.OKBLUE}Neuro Ai{bcolors.ENDC}]"
+
+
+def api(token_, project_name, verbosity):
     global _token
+    global  _project
     global VERBOSITY
     _token = token_
     VERBOSITY = verbosity
     if VERBOSITY != MIN_VERBOSITY:
-        print("Verbosity level set to {}".format(VERBOSITY))
-    params = {"token": _token}
+        npu_print(f"Verbosity level set to {VERBOSITY}")
+    params = {"token": _token, "project_name": project_name}
     response = requests.get(TOKEN_URL, params=params)
     if response.status_code == 200:
-        print("Token successfully authenticated")
+        npu_print("Token successfully authenticated")
+        _project = response.json()
+        npu_print(f"Using project: {project_name}")
         return response
     else:
         raise ValueError(response.text)
@@ -47,6 +70,10 @@ def getVerbosity():
     return VERBOSITY
 
 
+def get_project():
+    return _project
+
+
 def getResponse(response):
     try:
         return response.json()
@@ -88,6 +115,7 @@ def checkModel(model):
 
 
 def check_model_type(model, params):
+    from .Task import Task
     if isinstance(model, Model):
         params["model_name"] = model.name
         params["model_attr"] = model.attr
@@ -98,6 +126,7 @@ def check_model_type(model, params):
 
 
 def check_data_type(data, param_name, params):
+    from .Task import Task
     if isinstance(data, Dataset):
         params[param_name + "_name"] = data.id
     elif isinstance(data, str) and not ObjectId.is_valid(data):
@@ -106,7 +135,7 @@ def check_data_type(data, param_name, params):
         params[param_name + "Id"] = data
 
 
-def checkData(data, name=""):
+def check_data(data, name=""):
     if not isinstance(name, str):
         raise ValueError("Name given is not valid. Please supply a string.")
     if isinstance(data, (str, dict)):
@@ -114,9 +143,9 @@ def checkData(data, name=""):
     elif isinstance(data, Dataset):
         return data
     elif isinstance(data, DataLoader):
-        response = uploadDataLoader(data, name)
+        response = upload_data_loader(data, name)
     else:
-        response = uploadData(data, name)
+        response = upload_data(data, name)
     status_code = response.status_code
     if status_code not in (204, 200, 201):
         raise ConnectionAbortedError("Data upload has not worked: {}".format(response.content))
@@ -124,7 +153,7 @@ def checkData(data, name=""):
         response = getResponse(response)
     if isinstance(response, dict) and status_code == 200:
         message = response.get("message")
-        print(message)
+        npu_print(message)
         response = response["id"]
     return response
 
@@ -144,30 +173,14 @@ def gen(dl):
         yield save_data(data_part)
 
 
-# class UploadBar(ChargingBar):
-#     suffix = bar_suffix + " || %(index_bytes)s / %(max_bytes)s"
-
-    # @property
-    # def index_bytes(self):
-    #     return convert_size(self.index)
-    #
-    # @property
-    # def max_bytes(self):
-    #     return convert_size(self.max)
-
-
 def create_callback(encoder):
     encoder_len = encoder.len
-    bar = tqdm(desc="Uploading", unit="B", unit_scale=True, total=encoder_len, unit_divisor=1024)
-              # bar_format="{desc}: {percentage}%|{bar}| remaining: {remaining} || elapsed: {elapsed} ")
-    # bar = UploadBar('Uploading', max=encoder_len)
+    bar = tqdm(desc=f"{NEURO_AI_STR} Uploading", unit="B", unit_scale=True, total=encoder_len, unit_divisor=1024)
 
     def callback(monitor):
         bar.n = monitor.bytes_read
         bar.refresh()
-        # bar.goto(monitor.bytes_read)
         if monitor.bytes_read == encoder_len:
-            # bar.finish()
             bar.close()
     return callback
 
@@ -185,73 +198,75 @@ def create_upload(file):
     })
 
 
-def uploadDataLoader(dl, name=""):
-    length = len(dl)
+def upload_data_loader(dl, name=""):
     if VERBOSITY >= MID_VERBOSITY:
-        print("Hashing data locally...")
-    hash, size = dl.hash()
+        npu_print("Hashing data locally...")
+    hash, size, length = dl.hash()
     params = {"token": getToken(), "hash": hash, "collection": 1, "chunked": True, "is_last": False, "size": size,
-              "given_name": name, "input_shape": dl.shape}
+              "given_name": name, "input_shape": dl.shape, "project": get_project()}
     # params = {"token": getToken(), "hash": hash, "collection": 1, "size": size, "given_name": name}
-    print("Checking if data is on servers...")
+    npu_print("Checking if data is on servers...")
     response = requests.get(HASH_URL, params=params)
     if response.status_code == 200:
         if VERBOSITY >= MID_VERBOSITY:
-            print("Data already uploaded. Will not reupload.")
+            npu_print("Data already uploaded. Will not reupload.")
         return response
-    print("Data not on servers. Starting to upload. Total size of data is {}".format(convert_size(size)))
+    npu_print("Data not on servers. Starting to upload. Total size of data is {}".format(convert_size(size)))
     if length == 1:
-        return uploadData(next(dl.numpy()), name)
-    print("{} chunks to upload...".format(length))
+        return upload_data(next(dl.numpy()), name)
+    npu_print("{} chunks to upload...".format(length))
     for i, data_part in enumerate(dl.numpy()):
         if VERBOSITY >= MID_VERBOSITY:
-            print("Uploading chunk {} out of {}...".format(i + 1, length))
+            npu_print("Uploading chunk {} out of {}...".format(i + 1, length))
         if i == length - 1:
             params["is_last"] = True
         file = save_data(data_part)
         monitor = get_progress_bar_uploader(file)
         response = requests.post(UPLOAD_DATA_URL, data=monitor,
                                  headers={'Content-Type': monitor.content_type}, params=params)
-        # response = requests.post(UPLOAD_DATA_URL, files=files, params=params)
     return response
 
 
-def uploadData(data, name=""):
+def upload_data(data, name=""):
     if VERBOSITY >= FULL_VERBOSITY:
-        print("Saving data locally...")
+        npu_print("Saving data locally...")
     if isinstance(data, str):
         file = open(data, "rb")
     else:
         file = save_data(data)
     if VERBOSITY >= FULL_VERBOSITY:
-        print("Hashing...")
+        npu_print("Hashing...")
     hash = hashlib.md5()
-    size = 0
     for piece in read_in_chunks(file):
-        size += len(piece)
         hash.update(piece)
+    size = file.tell()
     hash = hash.hexdigest()
-    print("Checking if data is on servers...")
-    params = {"token": getToken(), "hash": hash, "collection": 1, "given_name": name}
-    response = requests.get(HASH_URL, params=params)
+    npu_print("Checking if data is on servers...")
+    params = {"token": getToken(), "hash": hash, "collection": 1, "given_name": name, "project": get_project()}
+    response = requests.get(HASH_URL, params=params, json=params)
     if response.status_code == 200:
         if VERBOSITY >= MID_VERBOSITY:
-            print("Data already on servers. Returning result...")
+            npu_print("Data already on servers. Returning result...")
         file.close()
         return response
-    print("Data not found on servers. Total size of data is {}. Uploading now...".format(convert_size(size)))
+    npu_print("Data not found on servers. Total size of data is {}. Uploading now...".format(convert_size(size)))
     file.seek(0)
-    # files = {'file': file}
 
     monitor = get_progress_bar_uploader(file)
     response = requests.post(UPLOAD_DATA_URL, data=monitor,
-                             headers={'Content-Type': monitor.content_type}, params=params)
-    # response = requests.post(UPLOAD_DATA_URL, files=files, params=params)
+                             headers={'Content-Type': monitor.content_type}, params=params, json=params)
     if isinstance(data, str):
         file.close()
     return response
 
 
+def upload_sample(data, params):
+    required = (len(data[0]) if isinstance(data, (tuple, list)) else len(data)) > 10
+    if not required:
+        return False
+    data = [d[:10] for d in data] if isinstance(data, (tuple, list)) else data[:10]
+
+
 def hashData(data):
     pass
 
@@ -284,3 +299,13 @@ def determine_data(data):
         name = data.id
         data = data
     return data, name, start, end
+
+
+def npu_print(val, level="INFO"):
+
+    log_str = f"{NEURO_AI_STR} {utcnow_formatted()} - [{levels[level]}{level}{bcolors.ENDC}]: {val}"
+    print(f"{log_str}")
+
+
+def utcnow_formatted():
+    return utcnow().strftime("%H:%M:%S")
