@@ -2,8 +2,8 @@ import requests
 
 from .Dataset import Dataset
 from .Task import Task
-from .common import getToken, checkData, add_kwargs_to_params, checkModel, determine_data, validate_model, \
-    check_model_type, check_data_type
+from .common import getToken, check_data, add_kwargs_to_params, checkModel, determine_data, validate_model, \
+    check_model_type, check_data_type, get_project
 from .web.urls import PREDICT_URL
 
 
@@ -13,7 +13,7 @@ def predict(model, data, asynchronous=False, callback=None, **kwargs):
     #     cached_model = model.cache["model"]
     #     if not isinstance(data, (str, Dataset, dict)):
     #         validate_model(cached_model, data)
-    inference_data = checkData(data)
+    inference_data = check_data(data)
     task_id = model.task_id if isinstance(model, Task) else ""
     resp = predictApi(model, inference_data, task_id, **kwargs)
     task = Task(resp.json(), callback)
@@ -24,8 +24,8 @@ def predict(model, data, asynchronous=False, callback=None, **kwargs):
 
 def predictApi(model, data, task_id, **kwargs):
     data, data_name, start, end = determine_data(data)
-    params = {"token": getToken(), "task_id": task_id, "start": start, "end": end,
-              "data_name": data_name}
+    params = {"token": getToken(), "task_id": task_id, "data_start": start, "data_end": end,
+              "data_name": data_name, "project": get_project()}
     check_model_type(model, params)
     check_data_type(data, "data", params)
     params = add_kwargs_to_params(params, **kwargs)
