@@ -1,16 +1,20 @@
 from . import core, optim, loss as _loss, metrics as _metrics
 
 
-def api(token, verbosity=1):
+def api(token, project="Default", verbosity=1):
     """Use this function to get access to the API, providing your token. All subsequents API calls will use this token.
 
         :param token: Token from dashboard
         :type token: str
+        :param project: Project name to assign models/data/tasks to a certain project.
+        :type project: str
+        :param verbosity: Print level for client. Useful for debugging.
+        :type verbosity: int
     """
-    core.api(token, verbosity)
+    core.api(token, project, verbosity)
 
 
-def compile(model, input_shape=[], library="", model_label="", asynchronous=False):
+def compile(model, input_shape=None, library="", model_label="", asynchronous=False):
     """Use this to upload and compile your model. Compatible frameworks are:
 
         * Pytorch
@@ -30,6 +34,8 @@ def compile(model, input_shape=[], library="", model_label="", asynchronous=Fals
 
         :return: compiled model.
     """
+    if input_shape is None:
+        input_shape = []
     return core.compile(model, input_shape, library, model_label, asynchronous)
 
 
@@ -91,6 +97,10 @@ def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.S
         :type callback: function
 
     """
+    assert type(batch_size) is int
+    assert type(epochs) is int
+    assert batch_size > 0
+    assert epochs > 0
     if metrics is None:
         metrics = [_metrics.Accuracy]
     return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, metrics, trained_model_name,
